# polars-algo

`polars-algo` is an **internal sub-crate** of the [Polars](https://crates.io/crates/polars) library, designed to house algorithms built on Polars primitives.

**Important Note**: This crate is **not intended for external usage**. If you're looking to use Polars, please refer to the main [Polars crate](https://crates.io/crates/polars) instead.
